
<!-- physical chemical property data from endpoint summaries -->
<#macro physicalChemicalPropertiesTable _subject>
<#compress>

	<!-- Physicochemical properties table -->	
	<#global propertyToDataMap = {
		"Physical state" : 
			{"subType" : "GeneralInformation", 
			"listValuePath" : "KeyValueForChemicalSafetyAssessment.PhysicalState", 
			"postText" : "at 20°C and 101.3 kPa"},
		"Melting / freezing point" : 
			{"subType" : "Melting", 
			"valuePath" : "KeyValueForChemicalSafetyAssessment.MelFreezPoint", 
			"postText" : "at 101.3 kPa",
			"infoReq" : "Melting / freezing point"},
		"Boiling point" : 
			{"subType" : "BoilingPoint", 
			"valuePath" : "KeyValueForChemicalSafetyAssessment.BoilingPoint", 
			"postText" : "at 101.3 kPa",
			"infoReq" : "Boiling point"},
		"Relative density" : 
			{"subType" : "PcDensity", 
			"valuePath" : "KeyValueForChemicalSafetyAssessment.RelativeDensity", 
			"postText" : "at 20°C",
			"infoReq" : "Relative density",
			"recordSubType" : "Density"},
		"Granulometry" : 
			{"subType" : "ParticleSize",
			"infoReq" : "Granulometry",
			"recordSubType" : "Granulometry"},
		"Vapour pressure" : 
			{"subType" : "Vapour", 
			"valuePath" : "KeyValueForChemicalSafetyAssessment.VapourPressure", 
			"atValuePath" : "KeyValueForChemicalSafetyAssessment.TemperatureOf",
			"infoReq" : "Vapour pressure"},
		"Partition coefficient n-octanol/water (log value)" : 
			{"subType" : "PartitionCoefficient", 
			"preText" : "Log Kow (Log Pow):", 
			"valuePath" : "KeyValueForChemicalSafetyAssessment.LowKow", 
			"atValuePath" : "KeyValueForChemicalSafetyAssessment.TemperatureOf",
			"infoReq" : "Partition coefficient n-octanol/water (log value)",
			"recordSubType" : "Partition"},
		"Water solubility" : 
			{"subType" : "WaterSolubility", 
			"valuePath" : "KeyValueForChemicalSafetyAssessment.WaterSolubility", 
			"atValuePath" : "KeyValueForChemicalSafetyAssessment.TemperatureOf",
			"infoReq" : "Water solubility"},
		"Solubility in organic solvents / fat solubility" : 
			{"subType" : "SolubilityOrganic",
			"preText" : "Solubility in mg/100 g standard fat:",
			"valuePath" : "KeyValueForChemicalSafetyAssessment.SolubilityStandard", 
			"atValuePath" : "KeyValueForChemicalSafetyAssessment.AtTheTemperatureOf",
			"preText2" : "Solubility in organic solvents at 20°C:",
			"valuePath2" : "KeyValueForChemicalSafetyAssessment.SolubilitySolvents",
			"infoReq" : "Solubility in organic solvents / fat solubility"},
		"Surface tension" : 
			{"subType" : "SurfaceTension",
			"valuePath" : "KeyValueForChemicalSafetyAssessment.SurfaceTension",
			"postText" : "mN/m at 20°C and",
			"valuePath2" : "KeyValueForChemicalSafetyAssessment.Concentration",
			"postText2" : "mg/L",
			"infoReq" : "Surface tension"},
		"Flash point" : 
			{"subType" : "FlashPoint",
			"valuePath" : "KeyValueForChemicalSafetyAssessment.FlashPoint",
			"postText" : "at 1013 hPa",
			"infoReq" : "Flash point"},
		"Autoflammability / self-ignition temperature" : 
			{"subType" : "AutoFlammability",
			"valuePath" : "KeyValueForChemicalSafetyAssessment.AutoFlammability",
			"postText" : "at 1013 hPa",
			"infoReq" : "Self-ignition temperature"},
		"Flammability" : 
			{"subType" : "Flammability",
			"listValuePath" : "KeyValueChemicalAssessment.Flammability",
			"infoReq" : "Flammability"},
		"Explosive properties" : 
			{"subType" : "Explosiveness",
			"listValuePath" : "ResultsAndDiscussion.Explosiveness",
			"infoReq" : "Explosive properties"},
		"Oxidising properties" : 
			{"subType" : "OxidisingProperties",
			"listValuePath" : "KeyValueChemicalAssessment.Oxidising",
			"infoReq" : "Oxidising properties"},
		"Oxidation reduction potential" : 
			{"subType" : "OxidReduction",
			"preText" : "Oxidation reduction potential in mV:",
			"valuePath" : "KeyValueForChemicalSafetyAssessment.ReductionPotential", 
			"atValuePath" : "KeyValueForChemicalSafetyAssessment.AtTheTemperatureOf",
			"infoReq" : "Oxidation reduction potential",
			"recordSubType" : "OxidationReduction"},
		"Stability in organic solvents and identity of relevant degradation products" : 
			{"subType" : "StabilityOrganic",
			"infoReq" : "Stability in organic solvents and identity of relevant degradation products"},
		"Storage stability and reactivity towards container material" : 
			{"subType" : "StorageStability",
			"infoReq" : "Reactivity towards container material"},
		"Stability: thermal, sunlight, metals" : 
			{"subType" : "StabilityThermal",
			"infoReq" : "Thermal stability"},
		"pH" : 
			{"subType" : "pH"},
		"Dissociation constant" : 
			{"subType" : "Dissociation",
			"preText" : "pKa at 20°C:",
			"valuePath" : "KeyValueForChemicalSafetyAssessment.pka",
			"infoReq" : "Dissociation constant",
			"recordSubType" : "DissociationConstant"},
		"Viscosity" : 
			{"subType" : "Viscosity",
			"preText" : "Viscosity:",
			"valuePath" : "KeyValueForChemicalSafetyAssessment.Viscosity",
			"atValuePath" : "KeyValueForChemicalSafetyAssessment.AtTheTemperatureOf",
			"infoReq" : "Viscosity"},
		"Self-reactive substances" : 
			{"subType" : "SelfReactiveSubstances",
			"infoReq" : "Self-reactive substances"},
		"Organic peroxide" : 
			{"subType" : "OrganicPeroxide",
			"infoReq" : "Organic peroxide"},
		"Corrosive to metals" : 
			{"subType" : "CorrosiveToMetals",
			"infoReq" : "Corrosive to metals"},
		"Gasses under pressure" : 
			{"subType" : "GasesUnderPressure",
			"infoReq" : "Gasses under pressure"}
	}/>
	
	<#assign properties = propertyToDataMap?keys />

	<#if properties?has_content>	
	
	<table border="1">
		<title>Physicochemical properties</title>
		<#if studyandsummaryCom.assessmentEntitiesExist && csrRelevant??>
			<col width="18%" />
			<col width="34%" />
			<col width="33%" />
			<col width="15%" />
		<#else/>
			<col width="20%" />
			<col width="40%" />
			<col width="40%" />
		</#if>
		<tbody>
			<tr>
				<th><?dbfo bgcolor="#FBDDA6" ?><emphasis role="bold">Property</emphasis></th>
				<th><?dbfo bgcolor="#FBDDA6" ?><emphasis role="bold">Value used for CSA / Discussion</emphasis></th>
				<th><?dbfo bgcolor="#FBDDA6" ?><emphasis role="bold">Description of key information</emphasis></th>
				<#if darRelevant?? && rarRelevant??>
					<th><?dbfo bgcolor="#FBDDA6" ?><emphasis role="bold">Literature references of studies linked ot summary</emphasis></th>
				</#if>
				<#if studyandsummaryCom.assessmentEntitiesExist && csrRelevant??>
					<th><?dbfo bgcolor="#FBDDA6" ?><emphasis role="bold">Assessment entity linked</emphasis></th>
				</#if>
			</tr>
			
			<#list properties as property>
		
				<#assign propertyData = propertyToDataMap[property] />
				<#assign summaryList = iuclid.getSectionDocumentsForParentKey(_subject.documentKey, "ENDPOINT_SUMMARY", propertyData["subType"]) />

				<#assign usespan = true />
				
				<#list summaryList as summary>
					<tr>
						<!-- Property -->
						<#if usespan>
							<td  rowspan="${summaryList?size}">
								<#assign docUrl=iuclid.webUrl.documentView(summary.documentKey) />
								<#if docUrl?has_content>
								<ulink url="${docUrl}">${property!}</ulink>
									<#else>
									${property!}
								</#if>
							</td>
							<#assign usespan = false />
						</#if>
						<!-- Value used for CSA / Discussion -->
						<td>						
						<#if isValueForCSARelevant(summary, propertyData)>
							<para><emphasis role="bold"><@valueForCSA summary propertyData/></emphasis></para>
						</#if>							
							<@com.richText summary.Discussion.Discussion/>
						</td>
						<!-- Description of key information -->
						<td>
							<@com.richText summary.KeyInformation.KeyInformation/>
						</td>						
						<!-- Reference from summary to endpoint study record's literature references -->
						<#if darRelevant?? && rarRelevant??>
							<td>
								<@literatureReferencesLinkedToSummary summary />
							</td>
						</#if>
						<#if studyandsummaryCom.assessmentEntitiesExist && csrRelevant??>
							<!-- Assessment entity linked -->
							<td>
								<#assign aeList = studyandsummaryCom.getAssessmentEntitiesLinkedToSummary(summary)/>
								<#list aeList as ae>
								<#if ae.AssessmentEntityName?has_content>
									<para><@com.text ae.AssessmentEntityName/></para>
									<#else>
									<para>--</para>
									</#if>
								</#list>
							</td>
						</#if>
					</tr>
				</#list>
			</#list>
		</tbody>
	</table>
	</#if>
	
	
	<!-- Additional physicochemical properties table -->
	<#global additionalPropertyToDataMap = {
		"Agglomeration / aggregation" : 
			{"subType" : "AgglomerationAggregation",
			"infoReq" : "Nanomaterial agglomeration / aggregation"},
		"Crystalline phase" : 
			{"subType" : "CrystallinePhase",
			"infoReq" : "Nanomaterial crystalline phase"},
		"Crystallite and grain size" : 
			{"subType" : "CrystalliteGrainSize",
			"infoReq" : "Nanomaterial crystallite and grain size"},
		"Aspect ratio / shape" : 
			{"subType" : "AspectRatioShape",
			"infoReq" : "Nanomaterial aspect ratio / shape"},
		"Specific surface area" : 
			{"subType" : "SpecificSurfaceArea",
			"infoReq" : "Nanomaterial specific surface area"},
		"Zeta potential" : 
			{"subType" : "ZetaPotential",
			"infoReq" : "Nanomaterial Zeta potential"},
		"Surface chemistry" : 
			{"subType" : "SurfaceChemistry",
			"infoReq" : "Nanomaterial surface chemistry"},
		"Dustiness" : 
			{"subType" : "Dustiness",
			"infoReq" : "Nanomaterial dustiness"},
		"Porosity" : 
			{"subType" : "Porosity",
			"infoReq" : "Nanomaterial porosity"},
		"Pour density" : 
			{"subType" : "PourDensity",
			"infoReq" : "Nanomaterial pour density"},
		"Photocatalytic activity" : 
			{"subType" : "PhotocatalyticActivity",
			"infoReq" : "Nanomaterial photocatalytic activityy"},
		"Radical formation potential" : 
			{"subType" : "RadicalFormationPotential",
			"infoReq" : "Nanomaterial radical formation potential"},
		"Catalytic activity" : 
			{"subType" : "CatalyticActivity",
			"infoReq" : "Nanomaterial catalytic activity"}
	}/>
	
	<#assign properties = additionalPropertyToDataMap?keys />

	<#if properties?has_content>
		<#assign existsAdditionalPhysChemPropContent = false />
		
		<#assign additionalPhysChemPropContent>
			<@com.emptyLine/>
			<table border="1">
				<title>Additional physicochemical properties of nanomaterial</title>
				<#if studyandsummaryCom.assessmentEntitiesExist && csrRelevant??>
					<col width="18%" />
					<col width="34%" />
					<col width="33%" />
					<col width="15%" />
				<#else/>
					<col width="20%" />
					<col width="40%" />
					<col width="40%" />
				</#if>
				<tbody>
					<tr>
						<th><?dbfo bgcolor="#FBDDA6" ?><emphasis role="bold">Property</emphasis></th>
						<th><?dbfo bgcolor="#FBDDA6" ?><emphasis role="bold">Description of key information</emphasis></th>
						<th><?dbfo bgcolor="#FBDDA6" ?><emphasis role="bold">Value used for CSA / Discussion</emphasis></th>
						<#if studyandsummaryCom.assessmentEntitiesExist && csrRelevant??>
							<th><?dbfo bgcolor="#FBDDA6" ?><emphasis role="bold">Assessment entity linked</emphasis></th>
						</#if>
					</tr>
					
					<#list properties as property>
				
						<#assign propertyData = additionalPropertyToDataMap[property] />
						<#assign summaryList = iuclid.getSectionDocumentsForParentKey(_subject.documentKey, "ENDPOINT_SUMMARY", propertyData["subType"]) />

						<#assign usespan = true />
						
						<#list summaryList as summary>
							<#assign existsAdditionalPhysChemPropContent = true />
							<tr>
								<!-- Property -->
								<#if usespan>
									<td  rowspan="${summaryList?size}">
										${property!}
									</td>
									<#assign usespan = false />
								</#if>
								<!-- Description of key information -->
								<td>
									<@com.richText summary.KeyInformation.KeyInformation/>
								</td>
								<!-- Value used for CSA / Discussion -->
								<td>
									<@com.richText summary.Discussion.Discussion/>
								</td>
								<#if studyandsummaryCom.assessmentEntitiesExist && csrRelevant??>
									<!-- Assessment entity linked -->
									<td>
										<#assign aeList = studyandsummaryCom.getAssessmentEntitiesLinkedToSummary(summary)/>
										<#list aeList as ae>
											<#if ae.AssessmentEntityName?has_content>
												<para><@com.text ae.AssessmentEntityName/></para>
											<#else>
												<para>--</para>
											</#if>
										</#list>
									</td>
								</#if>
							</tr>
						</#list>
					</#list>
				</tbody>
			</table>
			<@com.emptyLine/>
		</#assign>
		
		<#if existsAdditionalPhysChemPropContent>
			${additionalPhysChemPropContent}
		</#if>
	</#if>
	
</#compress>
</#macro>

<!-- Summary discussion of physical chemical properties -->
<#macro physicalChemicalPropertiesSummary _subject>
<#compress>

<#assign summaryList = iuclid.getSectionDocumentsForParentKey(_subject.documentKey, "ENDPOINT_SUMMARY", "PhysicalChemicalProperties") />
	
	<#if summaryList?has_content>
		<para><emphasis role="HEAD-WoutNo">Discussion of physicochemical properties</emphasis></para>
	</#if>
	
	<#if summaryList?has_content>
		<#assign printSummaryName = summaryList?size gt 1 />	
		<#list summaryList as summary>
			<@com.emptyLine/>
			<@studyandsummaryCom.endpointSummary summary "" printSummaryName/>
		</#list>
	</#if>
</#compress>
</#macro>
						
<!-- Macros and functions -->
<#function isValueForCSARelevant summary propertyData>
	<#if propertyData["listValuePath"]?has_content>
		<#local valuePath = "summary." + propertyData["listValuePath"] />
		<#local value = valuePath?eval />
	</#if>
	<#if propertyData["valuePath"]?has_content>
		<#local valuePath = "summary." + propertyData["valuePath"] />
		<#local value = valuePath?eval />
	</#if>
	<#if value?has_content>
		<#return true>
	</#if>
	<#return false>
</#function>

<#macro valueForCSA summary propertyData>
<#compress>
	<#-- listValuePath -->
	<#if propertyData["listValuePath"]?has_content>
		<#local valuePath = "summary." + propertyData["listValuePath"] />
		<@com.picklist valuePath?eval />
	</#if>
	
	<#-- preText -->
	${propertyData["preText"]!}
	
	<#-- valuePath -->
	<#if propertyData["valuePath"]?has_content>
		<#local valuePath = "summary." + propertyData["valuePath"] />
		<#local value = valuePath?eval />
		<#if value?is_number>
			<@com.number value />
		<#else/>
			<@com.quantity value />
		</#if>
	</#if>
	
	<#-- atValuePath -->
	<#if propertyData["atValuePath"]?has_content>
		<#local valuePath = "summary." + propertyData["atValuePath"] />
		<#local value = valuePath?eval />
		at <@com.quantity value />
	</#if>
	
	<#-- postText -->
	${propertyData["postText"]!}
	
	<#-- preText2 -->
	<#if propertyData["preText2"]?has_content>
		<?linebreak?>
		${propertyData["preText2"]!}
	</#if>
	
	<#-- valuePath2 -->
	<#if propertyData["valuePath2"]?has_content>
		<#local valuePath = "summary." + propertyData["valuePath2"] />
		<#local value = valuePath?eval />
		<#if value?is_number>
			<@com.number value />
		<#else/>
			<@com.quantity value />
		</#if>
	</#if>
	
	<#-- postText2 -->
	${propertyData["postText2"]!}
</#compress>
</#macro>

<#macro literatureReferencesLinkedToSummary summary >
<#compress>
<#if summary.LinkToRelevantStudyRecord.Link?has_content>
	<#list summary.LinkToRelevantStudyRecord.Link as studyReferenceLinkedToSummary>
	<#assign studyReference = iuclid.getDocumentForKey(studyReferenceLinkedToSummary) />
		<#assign literatureReference = studyReference.DataSource.Reference />
		<#if literatureReference?has_content>
		<#list literatureReference as item>
			<#if item?has_content>
			<#assign reference = iuclid.getDocumentForKey(item) />
			<#if reference?has_content && studyReference?has_content>
				
				<#if reference.GeneralInfo.Author?has_content>
				<para><@com.text reference.GeneralInfo.Author /></para></#if>
				
				<para>
				<#if reference.GeneralInfo.ReferenceYear?has_content>
				<@com.number reference.GeneralInfo.ReferenceYear /> </#if>
				
				<#if reference.GeneralInfo.ReportNo?has_content>
				(<@com.text reference.GeneralInfo.ReportNo />)</#if>
				</para>
				
			</#if>
			</#if><#if item_has_next><@com.emptyLine/></#if>
		</#list>
		</#if>
			
	</#list>
</#if>
</#compress>
</#macro>